@@ -67,6 +67,13 @@ enum Command {
 
         #[structopt(flatten)]
         period_grouping: PeriodGroup,
+
+        /// Whether to display as calendar table
+        #[structopt(long = "--calendar")]
+        calendar: bool,
+        /// Do not display summary
+        #[structopt(long = "--no-summary")]
+        no_summary: bool,
     },
 }
 
@@ -130,8 +137,8 @@ pub struct CommonOpts {
     pub exchange: Option<String>,
 
     /// TODO Date format
-    #[structopt(long = "--date-format")]
-    date_format: Option<String>,
+    #[structopt(long = "--date-format", default_value = "%y-%b-%d")]
+    pub date_format: String,
 
     #[structopt(long = "--force-color")]
     force_color: bool,
@@ -161,34 +168,10 @@ pub struct CommonOpts {
     /// Whether to collapse postings from the same account in the same transaction
     #[structopt(long = "--collapse")]
     pub collapse: bool,
-}
 
-impl CommonOpts {
-    pub fn new() -> Self {
-        CommonOpts {
-            input_file: PathBuf::new(),
-            args_only: false,
-            init_file: None,
-            depth: None,
-            query: vec![],
-            real: false,
-            begin: None,
-            end: None,
-            period: None,
-            now: None,
-            no_balance_check: false,
-            exchange: None,
-            date_format: None,
-            force_color: false,
-            force_pager: false,
-            effective: false,
-            strict: false,
-            pedantic: false,
-            unrealized_gains: None,
-            unrealized_losses: None,
-            collapse: false,
-        }
-    }
+    /// Show the other postings in the transaction
+    #[structopt(long = "--related")]
+    pub related: bool,
 }
 
 /// Groups of time
@@ -211,6 +194,9 @@ const NO_INIT_FILE_FLAG: &str = "--args-only";
 const LEDGER_PATHS_UNDER_DIR: &str = "~/.ledgerrc";
 const LEDGER_PATHS: &str = ".ledgerrc";
 
+/// Load parameters from an external configuration file
+///
+/// It checks whether ```--args-only``` has been passed so that the configuration file is ignored
 fn init_paths(args: Vec<String>) -> Result<Vec<String>, ()> {
     let mut possible_paths: Vec<String> = Vec::new();
     let mut ignore_init = false;
@@ -265,6 +251,7 @@ pub fn run_app(input_args: Vec<String>) -> Result<(), ()> {
                     println!("dinero-rs v{}", VERSION);
 
                     let start = Instant::now();
+
                     let mut ledger = Ledger::try_from(&opt.options).unwrap();
                     let duration = start.elapsed();
                     println!(
@@ -398,6 +385,8 @@ fn execute_command(opt: Opt, maybe_ledger: Option<Ledger>) -> Result<(), ()> {
             cash_flows,
             assets_value,
             period_grouping,
+            calendar,
+            no_summary,
         } => {
             if options.force_color {
                 env::set_var("CLICOLOR_FORCE", "1");
@@ -408,6 +397,8 @@ fn execute_command(opt: Opt, maybe_ledger: Option<Ledger>) -> Result<(), ()> {
                 cash_flows,
                 assets_value,
                 Frequency::from(period_grouping),
+                calendar,
+                !no_summary,
             )
         }
         Command::Commodities(options) => {
