@@ -525,7 +525,8 @@ pub trait FromDirective {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
+    use structopt::StructOpt;
+
     use crate::{parser::Tokenizer, CommonOpts};
 
     #[test]
@@ -537,7 +538,7 @@ mod tests {
             "
             .to_string(),
         );
-        let options = CommonOpts::new();
+        let options = CommonOpts::from_iter(["", "-f", ""].iter());
 
         let items = tokenizer.tokenize(&options);
         let ledger = items.to_ledger(&options).unwrap();
