@@ -1,9 +1,8 @@
 use super::super::Rule;
 use std::collections::HashSet;
-use std::usize;
 
-use crate::models::{Comment, Currency};
-use crate::parser::utils::{parse_string, parse_usize};
+use crate::models::{Comment, Currency, CurrencyDisplayFormat};
+use crate::parser::utils::parse_string;
 use crate::parser::Tokenizer;
 
 use pest::iterators::Pair;
@@ -15,7 +14,6 @@ impl<'a> Tokenizer<'a> {
         let mut note: Option<String> = None;
         let mut format: Option<String> = None;
         let mut comments: Vec<Comment> = vec![];
-        let mut precision: Option<usize> = None;
         let mut default = false;
         let mut aliases = HashSet::new();
 
@@ -32,7 +30,6 @@ impl<'a> Tokenizer<'a> {
                         }
                         Rule::note => note = Some(parse_string(property.next().unwrap())),
                         Rule::format => format = Some(parse_string(property.next().unwrap())),
-                        Rule::precision => precision = Some(parse_usize(property.next().unwrap())),
                         _ => {}
                     }
                 }
@@ -51,11 +48,10 @@ impl<'a> Tokenizer<'a> {
             currency.set_note(note.unwrap());
         }
         if format.is_some() {
-            currency.set_format(format.unwrap());
-        }
-        if precision.is_some() {
-            currency.set_precision(precision.unwrap())
+            currency.format = format.clone();
+            currency.set_format(&CurrencyDisplayFormat::from(format.unwrap().as_str()));
         }
+
         currency
     }
 }
